@@ -16,7 +16,7 @@ mod impls;
     Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash, SerializeDisplay, DeserializeFromStr,
 )]
 #[cfg_attr(feature = "graphql", derive(juniper::GraphQLEnum))]
-#[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
+#[cfg_attr(feature = "iterator", derive(enum_iterator::IntoEnumIterator))]
 pub enum AzureRegion {
     CentralUs,
     EastUs,
